==> qt-creator-opensource-src-3.0.0.zip: qt-creator-opensource-src-3.0.0/src/plugins/qnx/bardescriptoreditorpermissionswidget.h <==
/**************************************************************************
**
** Copyright (C) 2013 BlackBerry Limited. All rights reserved.
**
** Contact: BlackBerry (qt@blackberry.com)
** Contact: KDAB (info@kdab.com)
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QNX_INTERNAL_BARDESCRIPTOREDITORPERMISSIONSWIDGET_H
#define QNX_INTERNAL_BARDESCRIPTOREDITORPERMISSIONSWIDGET_H

#include "bardescriptoreditorabstractpanelwidget.h"

namespace Qnx {
namespace Internal {

class BarDescriptorPermissionsModel;

namespace Ui {
class BarDescriptorEditorPermissionsWidget;
}

class BarDescriptorEditorPermissionsWidget : public BarDescriptorEditorAbstractPanelWidget
{
    Q_OBJECT

public:
    explicit BarDescriptorEditorPermissionsWidget(QWidget *parent = 0);
    ~BarDescriptorEditorPermissionsWidget();

    void clear();

    QStringList checkedPermissions() const;
    void checkPermission(const QString &identifier);

private:
    Ui::BarDescriptorEditorPermissionsWidget *m_ui;

    BarDescriptorPermissionsModel *m_permissionsModel;
};


} // namespace Internal
} // namespace Qnx
#endif // QNX_INTERNAL_BARDESCRIPTOREDITORPERMISSIONSWIDGET_H

==> qt-creator-opensource-src-3.1.2.zip: qt-creator-opensource-src-3.1.2/src/plugins/qnx/bardescriptoreditorpermissionswidget.h <==
/**************************************************************************
**
** Copyright (C) 2014 BlackBerry Limited. All rights reserved.
**
** Contact: BlackBerry (qt@blackberry.com)
** Contact: KDAB (info@kdab.com)
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QNX_INTERNAL_BARDESCRIPTOREDITORPERMISSIONSWIDGET_H
#define QNX_INTERNAL_BARDESCRIPTOREDITORPERMISSIONSWIDGET_H

#include "bardescriptoreditorabstractpanelwidget.h"

namespace Qnx {
namespace Internal {

class BarDescriptorPermissionsModel;

namespace Ui { class BarDescriptorEditorPermissionsWidget; }

class BarDescriptorEditorPermissionsWidget : public BarDescriptorEditorAbstractPanelWidget
{
    Q_OBJECT

public:
    explicit BarDescriptorEditorPermissionsWidget(QWidget *parent = 0);
    ~BarDescriptorEditorPermissionsWidget();

protected:
    void updateWidgetValue(BarDescriptorDocument::Tag tag, const QVariant &value);
    void emitChanged(BarDescriptorDocument::Tag tag);

private:
    QStringList checkedPermissions() const;
    void checkPermission(const QString &identifier);

    Ui::BarDescriptorEditorPermissionsWidget *m_ui;

    BarDescriptorPermissionsModel *m_permissionsModel;
};


} // namespace Internal
} // namespace Qnx
#endif // QNX_INTERNAL_BARDESCRIPTOREDITORPERMISSIONSWIDGET_H
